@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'I`m eager to assist you! Please provide me with the features you would like me to summarize into one sentence for your class summary.',
                                   class => 'Import2DimensionStringArrayOption',
                                   required => [], # TODO
 }                                 );
@@ -130,7 +130,7 @@ __PACKAGE__->method_documentation({
      'first_row' => {
      	datatype => 'int',
      	base_name => 'FirstRow',
-     	description => '',
+     	description => 'This class has a property called FirstRow of type integer with a public getter and setter.',
      	format => '',
      	read_only => '',
      		},
