@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents options of saving .json file.',
                                   class => 'JsonSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -129,28 +129,28 @@ __PACKAGE__->method_documentation({
      'export_area' => {
      	datatype => 'CellArea',
      	base_name => 'ExportArea',
-     	description => '',
+     	description => 'Gets or sets the exporting range.',
      	format => '',
      	read_only => '',
      		},
      'has_header_row' => {
      	datatype => 'boolean',
      	base_name => 'HasHeaderRow',
-     	description => '',
+     	description => 'Indicates whether the range contains header row.',
      	format => '',
      	read_only => '',
      		},
      'export_as_string' => {
      	datatype => 'boolean',
      	base_name => 'ExportAsString',
-     	description => '',
+     	description => 'Exports the string value of the cells to json.',
      	format => '',
      	read_only => '',
      		},
      'indent' => {
      	datatype => 'string',
      	base_name => 'Indent',
-     	description => '',
+     	description => 'Indicates the indent.',
      	format => '',
      	read_only => '',
      		},
@@ -208,41 +208,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'merge_areas' => {
-     	datatype => 'boolean',
-     	base_name => 'MergeAreas',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'sort_external_names' => {
-     	datatype => 'boolean',
-     	base_name => 'SortExternalNames',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'check_excel_restriction' => {
-     	datatype => 'boolean',
-     	base_name => 'CheckExcelRestriction',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'update_smart_art' => {
-     	datatype => 'boolean',
-     	base_name => 'UpdateSmartArt',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'encrypt_document_properties' => {
-     	datatype => 'boolean',
-     	base_name => 'EncryptDocumentProperties',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -259,12 +224,7 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean',
-    'merge_areas' => 'boolean',
-    'sort_external_names' => 'boolean',
-    'check_excel_restriction' => 'boolean',
-    'update_smart_art' => 'boolean',
-    'encrypt_document_properties' => 'boolean' 
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -279,12 +239,7 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'merge_areas' => 'MergeAreas',
-    'sort_external_names' => 'SortExternalNames',
-    'check_excel_restriction' => 'CheckExcelRestriction',
-    'update_smart_art' => 'UpdateSmartArt',
-    'encrypt_document_properties' => 'EncryptDocumentProperties' 
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
