@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options for pagination.',
                                   class => 'PaginatedSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,105 +128,105 @@ __PACKAGE__->method_documentation({
      'default_font' => {
      	datatype => 'string',
      	base_name => 'DefaultFont',
-     	description => '',
+     	description => 'When characters in the Excel are Unicode and not be set with correct font in cell style,They may appear as block in pdf,image.Set the DefaultFont such as MingLiu or MS Gothic to show these characters. If this property is not set, Aspose.Cells will use system default font to show these unicode characters.',
      	format => '',
      	read_only => '',
      		},
      'check_workbook_default_font' => {
      	datatype => 'boolean',
      	base_name => 'CheckWorkbookDefaultFont',
-     	description => '',
+     	description => 'When characters in the Excel are Unicode and not be set with correct font in cell style,They may appear as block in pdf,image.Set this to true to try to use workbook`s default font to show these characters first.',
      	format => '',
      	read_only => '',
      		},
      'check_font_compatibility' => {
      	datatype => 'boolean',
      	base_name => 'CheckFontCompatibility',
-     	description => '',
+     	description => 'Indicates whether to check font compatibility for every character in text.',
      	format => '',
      	read_only => '',
      		},
      'is_font_substitution_char_granularity' => {
      	datatype => 'boolean',
      	base_name => 'IsFontSubstitutionCharGranularity',
-     	description => '',
+     	description => 'Indicates whether to only substitute the font of character when the cell font is not compatibility for it.',
      	format => '',
      	read_only => '',
      		},
      'one_page_per_sheet' => {
      	datatype => 'boolean',
      	base_name => 'OnePagePerSheet',
-     	description => '',
+     	description => 'If OnePagePerSheet is true , all content of one sheet will output to only one page in result.The paper size of pagesetup will be invalid, and the other settings of pagesetup will still take effect.',
      	format => '',
      	read_only => '',
      		},
      'all_columns_in_one_page_per_sheet' => {
      	datatype => 'boolean',
      	base_name => 'AllColumnsInOnePagePerSheet',
-     	description => '',
+     	description => 'If AllColumnsInOnePagePerSheet is true , all column content of one sheet will output to only one page in result.The width of paper size of pagesetup will be ignored, and the other settings of pagesetup will still take effect.',
      	format => '',
      	read_only => '',
      		},
      'ignore_error' => {
      	datatype => 'boolean',
      	base_name => 'IgnoreError',
-     	description => '',
+     	description => 'Indicates if you need to hide the error while rendering.The error can be error in shape, image, chart rendering, etc.',
      	format => '',
      	read_only => '',
      		},
      'output_blank_page_when_nothing_to_print' => {
      	datatype => 'boolean',
      	base_name => 'OutputBlankPageWhenNothingToPrint',
-     	description => '',
+     	description => 'Indicates whether to output a blank page when there is nothing to print.',
      	format => '',
      	read_only => '',
      		},
      'page_index' => {
      	datatype => 'int',
      	base_name => 'PageIndex',
-     	description => '',
+     	description => 'Gets or sets the 0-based index of the first page to save.',
      	format => '',
      	read_only => '',
      		},
      'page_count' => {
      	datatype => 'int',
      	base_name => 'PageCount',
-     	description => '',
+     	description => 'Gets or sets the number of pages to save.',
      	format => '',
      	read_only => '',
      		},
      'printing_page_type' => {
      	datatype => 'string',
      	base_name => 'PrintingPageType',
-     	description => '',
+     	description => 'Indicates which pages will not be printed.',
      	format => '',
      	read_only => '',
      		},
      'gridline_type' => {
      	datatype => 'string',
      	base_name => 'GridlineType',
-     	description => '',
+     	description => 'Gets or sets gridline type.',
      	format => '',
      	read_only => '',
      		},
      'text_cross_type' => {
      	datatype => 'string',
      	base_name => 'TextCrossType',
-     	description => '',
+     	description => 'Gets or sets displaying text type when the text width is larger than cell width.',
      	format => '',
      	read_only => '',
      		},
      'default_edit_language' => {
      	datatype => 'string',
      	base_name => 'DefaultEditLanguage',
-     	description => '',
+     	description => 'Gets or sets default edit language.',
      	format => '',
      	read_only => '',
      		},
      'emf_render_setting' => {
      	datatype => 'string',
      	base_name => 'EmfRenderSetting',
-     	description => '',
+     	description => 'Setting for rendering Emf metafile.',
      	format => '',
      	read_only => '',
      		},
@@ -305,20 +305,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'check_excel_restriction' => {
-     	datatype => 'boolean',
-     	base_name => 'CheckExcelRestriction',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'encrypt_document_properties' => {
-     	datatype => 'boolean',
-     	base_name => 'EncryptDocumentProperties',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -349,9 +335,7 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean',
-    'check_excel_restriction' => 'boolean',
-    'encrypt_document_properties' => 'boolean' 
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -380,9 +364,7 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'check_excel_restriction' => 'CheckExcelRestriction',
-    'encrypt_document_properties' => 'EncryptDocumentProperties' 
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
