@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the Save Response.',
                                   class => 'SaveResponse',
                                   required => [], # TODO
 }                                 );
@@ -129,7 +129,7 @@ __PACKAGE__->method_documentation({
      'save_result' => {
      	datatype => 'SaveResult',
      	base_name => 'SaveResult',
-     	description => '',
+     	description => 'This class property represents a "SaveResult" XML element.',
      	format => '',
      	read_only => '',
      		},
