@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options of saving .xml file.',
                                   class => 'SpreadsheetML2003SaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'export_column_index_of_cell' => {
      	datatype => 'boolean',
      	base_name => 'ExportColumnIndexOfCell',
-     	description => '',
+     	description => 'The default value is false, it means that column index will be ignored if the cell is contiguous to the previous cell.',
      	format => '',
      	read_only => '',
      		},
      'is_indented_formatting' => {
      	datatype => 'boolean',
      	base_name => 'IsIndentedFormatting',
-     	description => '',
+     	description => 'Causes child elements to be indented.The default value is true.  If the value is false, it will reduce the size of the xml file',
      	format => '',
      	read_only => '',
      		},
      'limit_as_xls' => {
      	datatype => 'boolean',
      	base_name => 'LimitAsXls',
-     	description => '',
+     	description => 'Limit as xls, the max row index is 65535 and the max column index is 255.',
      	format => '',
      	read_only => '',
      		},
@@ -200,41 +200,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'merge_areas' => {
-     	datatype => 'boolean',
-     	base_name => 'MergeAreas',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'sort_external_names' => {
-     	datatype => 'boolean',
-     	base_name => 'SortExternalNames',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'check_excel_restriction' => {
-     	datatype => 'boolean',
-     	base_name => 'CheckExcelRestriction',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'update_smart_art' => {
-     	datatype => 'boolean',
-     	base_name => 'UpdateSmartArt',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'encrypt_document_properties' => {
-     	datatype => 'boolean',
-     	base_name => 'EncryptDocumentProperties',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -250,12 +215,7 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean',
-    'merge_areas' => 'boolean',
-    'sort_external_names' => 'boolean',
-    'check_excel_restriction' => 'boolean',
-    'update_smart_art' => 'boolean',
-    'encrypt_document_properties' => 'boolean' 
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -269,12 +229,7 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'merge_areas' => 'MergeAreas',
-    'sort_external_names' => 'SortExternalNames',
-    'check_excel_restriction' => 'CheckExcelRestriction',
-    'update_smart_art' => 'UpdateSmartArt',
-    'encrypt_document_properties' => 'EncryptDocumentProperties' 
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
