@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options of saving .sql file.',
                                   class => 'SqlScriptSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -129,98 +129,98 @@ __PACKAGE__->method_documentation({
      'check_if_table_exists' => {
      	datatype => 'boolean',
      	base_name => 'CheckIfTableExists',
-     	description => '',
+     	description => 'Check if the table name exists before creating',
      	format => '',
      	read_only => '',
      		},
      'column_type_map' => {
      	datatype => 'string',
      	base_name => 'ColumnTypeMap',
-     	description => '',
+     	description => 'Gets and sets the map of column type for different database.',
      	format => '',
      	read_only => '',
      		},
      'check_all_data_for_column_type' => {
      	datatype => 'boolean',
      	base_name => 'CheckAllDataForColumnType',
-     	description => '',
+     	description => 'Check all data to find columns` data type.',
      	format => '',
      	read_only => '',
      		},
      'add_blank_line_between_rows' => {
      	datatype => 'boolean',
      	base_name => 'AddBlankLineBetweenRows',
-     	description => '',
+     	description => 'Insert blank line between each data.',
      	format => '',
      	read_only => '',
      		},
      'separator' => {
      	datatype => 'string',
      	base_name => 'Separator',
-     	description => '',
+     	description => 'Gets and sets character separator of sql script.',
      	format => '',
      	read_only => '',
      		},
      'operator_type' => {
      	datatype => 'string',
      	base_name => 'OperatorType',
-     	description => '',
+     	description => 'Gets and sets the operator type of sql.',
      	format => '',
      	read_only => '',
      		},
      'primary_key' => {
      	datatype => 'int',
      	base_name => 'PrimaryKey',
-     	description => '',
+     	description => 'Represents which column is primary key of the data table.',
      	format => '',
      	read_only => '',
      		},
      'create_table' => {
      	datatype => 'boolean',
      	base_name => 'CreateTable',
-     	description => '',
+     	description => 'Indicates whether exporting sql of creating table.',
      	format => '',
      	read_only => '',
      		},
      'id_name' => {
      	datatype => 'string',
      	base_name => 'IdName',
-     	description => '',
+     	description => 'Gets and sets the name of id column.',
      	format => '',
      	read_only => '',
      		},
      'start_id' => {
      	datatype => 'int',
      	base_name => 'StartId',
-     	description => '',
+     	description => 'Gets and sets the start id.',
      	format => '',
      	read_only => '',
      		},
      'table_name' => {
      	datatype => 'string',
      	base_name => 'TableName',
-     	description => '',
+     	description => 'Gets and sets the table name.',
      	format => '',
      	read_only => '',
      		},
      'export_as_string' => {
      	datatype => 'boolean',
      	base_name => 'ExportAsString',
-     	description => '',
+     	description => 'Indicates whether exporting all data as string value.',
      	format => '',
      	read_only => '',
      		},
      'export_area' => {
      	datatype => 'CellArea',
      	base_name => 'ExportArea',
-     	description => '',
+     	description => 'Gets or sets the exporting range.',
      	format => '',
      	read_only => '',
      		},
      'has_header_row' => {
      	datatype => 'boolean',
      	base_name => 'HasHeaderRow',
-     	description => '',
+     	description => 'Indicates whether the range contains header row.',
      	format => '',
      	read_only => '',
      		},
@@ -278,41 +278,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'merge_areas' => {
-     	datatype => 'boolean',
-     	base_name => 'MergeAreas',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'sort_external_names' => {
-     	datatype => 'boolean',
-     	base_name => 'SortExternalNames',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'check_excel_restriction' => {
-     	datatype => 'boolean',
-     	base_name => 'CheckExcelRestriction',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'update_smart_art' => {
-     	datatype => 'boolean',
-     	base_name => 'UpdateSmartArt',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'encrypt_document_properties' => {
-     	datatype => 'boolean',
-     	base_name => 'EncryptDocumentProperties',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -339,12 +304,7 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean',
-    'merge_areas' => 'boolean',
-    'sort_external_names' => 'boolean',
-    'check_excel_restriction' => 'boolean',
-    'update_smart_art' => 'boolean',
-    'encrypt_document_properties' => 'boolean' 
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -369,12 +329,7 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'merge_areas' => 'MergeAreas',
-    'sort_external_names' => 'SortExternalNames',
-    'check_excel_restriction' => 'CheckExcelRestriction',
-    'update_smart_art' => 'UpdateSmartArt',
-    'encrypt_document_properties' => 'EncryptDocumentProperties' 
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
