@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents the options of saving .txt file.',
                                   class => 'TxtSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'quote_type' => {
      	datatype => 'string',
      	base_name => 'QuoteType',
-     	description => '',
+     	description => 'Gets or sets how to quote values in the exported text file.',
      	format => '',
      	read_only => '',
      		},
      'separator' => {
      	datatype => 'string',
      	base_name => 'Separator',
-     	description => '',
+     	description => 'Gets and sets char Delimiter of text file.',
      	format => '',
      	read_only => '',
      		},
      'separator_string' => {
      	datatype => 'string',
      	base_name => 'SeparatorString',
-     	description => '',
+     	description => 'Gets and sets the a string value as separator.',
      	format => '',
      	read_only => '',
      		},
      'always_quoted' => {
      	datatype => 'boolean',
      	base_name => 'AlwaysQuoted',
-     	description => '',
+     	description => 'Indicates whether always adding `"` for each field. If true then all values will be quoted; If false then values will only be quoted when needed(for example, when values contain special characters such as `"` , `\n` or separator character). Default is false.',
      	format => '',
      	read_only => '',
      		},
@@ -207,41 +207,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'merge_areas' => {
-     	datatype => 'boolean',
-     	base_name => 'MergeAreas',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'sort_external_names' => {
-     	datatype => 'boolean',
-     	base_name => 'SortExternalNames',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'check_excel_restriction' => {
-     	datatype => 'boolean',
-     	base_name => 'CheckExcelRestriction',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'update_smart_art' => {
-     	datatype => 'boolean',
-     	base_name => 'UpdateSmartArt',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'encrypt_document_properties' => {
-     	datatype => 'boolean',
-     	base_name => 'EncryptDocumentProperties',
-     	description => '',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -258,12 +223,7 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean',
-    'merge_areas' => 'boolean',
-    'sort_external_names' => 'boolean',
-    'check_excel_restriction' => 'boolean',
-    'update_smart_art' => 'boolean',
-    'encrypt_document_properties' => 'boolean' 
+    'validate_merged_areas' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -278,12 +238,7 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas',
-    'merge_areas' => 'MergeAreas',
-    'sort_external_names' => 'SortExternalNames',
-    'check_excel_restriction' => 'CheckExcelRestriction',
-    'update_smart_art' => 'UpdateSmartArt',
-    'encrypt_document_properties' => 'EncryptDocumentProperties' 
+    'validate_merged_areas' => 'ValidateMergedAreas' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
