@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# GetChartAreaRequest.name : The file name.  ,
-# GetChartAreaRequest.sheetName : The worksheet name.  ,
-# GetChartAreaRequest.chartIndex : The chart index.  ,
-# GetChartAreaRequest.folder : The folder where the file is situated.  ,
-# GetChartAreaRequest.storageName : The storage name where the file is situated.   
+# GetChartAreaRequest.name :   ,
+# GetChartAreaRequest.sheetName :   ,
+# GetChartAreaRequest.chartIndex :   ,
+# GetChartAreaRequest.folder :   ,
+# GetChartAreaRequest.storageName :    
 
 {
     my $params = {
@@ -75,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_chart_area' } = { 
-    	summary => 'Retrieve chart area description in the worksheet.',
+    	summary => '',
         params => $params,
         returns => 'ChartAreaResponse',
     };
@@ -87,7 +86,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/charts/{chartIndex}/chartArea';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/charts/{chartIndex}/chartArea';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -125,9 +124,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -141,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => 'The worksheet name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'chart_index' => {
      	datatype => 'int',
      	base_name => 'chartIndex',
-     	description => 'The chart index.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
