@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,9 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# GetWorkbookDefaultStyleRequest.name : The file name.  ,
-# GetWorkbookDefaultStyleRequest.folder : The folder where the file is situated.  ,
-# GetWorkbookDefaultStyleRequest.storageName : The storage name where the file is situated.   
+# GetWorkbookDefaultStyleRequest.name :   ,
+# GetWorkbookDefaultStyleRequest.folder :   ,
+# GetWorkbookDefaultStyleRequest.storageName :    
 
 {
     my $params = {
@@ -73,7 +72,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_workbook_default_style' } = { 
-    	summary => 'Retrieve the description of the default style for the workbook .',
+    	summary => '',
         params => $params,
         returns => 'StyleResponse',
     };
@@ -85,7 +84,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/defaultstyle';
+    my $_resource_path = '/cells/{name}/defaultstyle';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -111,9 +110,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -127,21 +123,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
