@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,22 +59,19 @@ sub new {
 
 
 # Run Operation Request
-# GetWorkbookRequest.name : The file name.  ,
-# GetWorkbookRequest.format : The conversion format(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers).  ,
-# GetWorkbookRequest.password : The password needed to open an Excel file.  ,
-# GetWorkbookRequest.isAutoFit : Specifies whether set workbook rows to be autofit.  ,
-# GetWorkbookRequest.onlySaveTable : Specifies whether only save table data.Only use pdf to excel.  ,
-# GetWorkbookRequest.folder : The folder where the file is situated.  ,
-# GetWorkbookRequest.outPath : Path to save the result. If it`s a single file, the `outPath` should encompass both the filename and extension. In the case of multiple files, the `outPath` should only include the folder.  ,
-# GetWorkbookRequest.storageName : The storage name where the file is situated.  ,
-# GetWorkbookRequest.outStorageName : The storage name where the output file is situated.  ,
-# GetWorkbookRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# GetWorkbookRequest.region : The regional settings for workbook.  ,
-# GetWorkbookRequest.pageWideFitOnPerSheet : The page wide fit on worksheet.  ,
-# GetWorkbookRequest.pageTallFitOnPerSheet : The page tall fit on worksheet.  ,
-# GetWorkbookRequest.onePagePerSheet : When converting to PDF format, one page per sheet.  ,
-# GetWorkbookRequest.onlyAutofitTable :   ,
-# GetWorkbookRequest.FontsLocation : Use Custom fonts.   
+# GetWorkbookRequest.name :   ,
+# GetWorkbookRequest.format :   ,
+# GetWorkbookRequest.password :   ,
+# GetWorkbookRequest.isAutoFit :   ,
+# GetWorkbookRequest.onlySaveTable :   ,
+# GetWorkbookRequest.folder :   ,
+# GetWorkbookRequest.outPath :   ,
+# GetWorkbookRequest.storageName :   ,
+# GetWorkbookRequest.outStorageName :   ,
+# GetWorkbookRequest.checkExcelRestriction :   ,
+# GetWorkbookRequest.region :   ,
+# GetWorkbookRequest.pageWideFitOnPerSheet :   ,
+# GetWorkbookRequest.pageTallFitOnPerSheet :    
 
 {
     my $params = {
@@ -86,7 +82,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_workbook' } = { 
-    	summary => 'Retrieve workbooks in various formats.',
+    	summary => '',
         params => $params,
         returns => 'string',
     };
@@ -98,7 +94,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}';
+    my $_resource_path = '/cells/{name}';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -162,23 +158,8 @@ sub run_http_request {
 
     if(defined $self->page_tall_fit_on_per_sheet){
         $query_params->{'pageTallFitOnPerSheet'} = $client->to_query_value($self->page_tall_fit_on_per_sheet);      
-    }
-
-    if(defined $self->one_page_per_sheet){
-        $query_params->{'onePagePerSheet'} = $client->to_query_value($self->one_page_per_sheet);      
-    }
-
-    if(defined $self->only_autofit_table){
-        $query_params->{'onlyAutofitTable'} = $client->to_query_value($self->only_autofit_table);      
-    }
-
-    if(defined $self->fonts_location){
-        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -192,113 +173,92 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'format' => {
      	datatype => 'string',
      	base_name => 'format',
-     	description => 'The conversion format(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers).',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => 'The password needed to open an Excel file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_auto_fit' => {
      	datatype => 'string',
      	base_name => 'isAutoFit',
-     	description => 'Specifies whether set workbook rows to be autofit.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'only_save_table' => {
      	datatype => 'string',
      	base_name => 'onlySaveTable',
-     	description => 'Specifies whether only save table data.Only use pdf to excel.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'out_path' => {
      	datatype => 'string',
      	base_name => 'outPath',
-     	description => 'Path to save the result. If it`s a single file, the `outPath` should encompass both the filename and extension. In the case of multiple files, the `outPath` should only include the folder.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'out_storage_name' => {
      	datatype => 'string',
      	base_name => 'outStorageName',
-     	description => 'The storage name where the output file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'region' => {
      	datatype => 'string',
      	base_name => 'region',
-     	description => 'The regional settings for workbook.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'page_wide_fit_on_per_sheet' => {
      	datatype => 'string',
      	base_name => 'pageWideFitOnPerSheet',
-     	description => 'The page wide fit on worksheet.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'page_tall_fit_on_per_sheet' => {
      	datatype => 'string',
      	base_name => 'pageTallFitOnPerSheet',
-     	description => 'The page tall fit on worksheet.',
-     	format => '',
-     	read_only => '',
-     		},
-     'one_page_per_sheet' => {
-     	datatype => 'string',
-     	base_name => 'onePagePerSheet',
-     	description => 'When converting to PDF format, one page per sheet.',
-     	format => '',
-     	read_only => '',
-     		},
-     'only_autofit_table' => {
-     	datatype => 'string',
-     	base_name => 'onlyAutofitTable',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'fonts_location' => {
-     	datatype => 'string',
-     	base_name => 'FontsLocation',
-     	description => 'Use Custom fonts.',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -317,10 +277,7 @@ __PACKAGE__->attribute_map( {
     'check_excel_restriction' => 'checkExcelRestriction',
     'region' => 'region',
     'page_wide_fit_on_per_sheet' => 'pageWideFitOnPerSheet',
-    'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet',
-    'one_page_per_sheet' => 'onePagePerSheet',
-    'only_autofit_table' => 'onlyAutofitTable',
-    'fonts_location' => 'FontsLocation' 
+    'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
