@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetColumnsRequest.name : The file name.  ,
-# GetWorksheetColumnsRequest.sheetName : The worksheet name.  ,
-# GetWorksheetColumnsRequest.offset : The workdook folder.  ,
+# GetWorksheetColumnsRequest.name :   ,
+# GetWorksheetColumnsRequest.sheetName :   ,
+# GetWorksheetColumnsRequest.offset :   ,
 # GetWorksheetColumnsRequest.count :   ,
-# GetWorksheetColumnsRequest.folder : The folder where the file is situated.  ,
-# GetWorksheetColumnsRequest.storageName : The storage name where the file is situated.   
+# GetWorksheetColumnsRequest.folder :   ,
+# GetWorksheetColumnsRequest.storageName :    
 
 {
     my $params = {
@@ -76,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_columns' } = { 
-    	summary => 'Retrieve descriptions of worksheet columns.',
+    	summary => '',
         params => $params,
         returns => 'ColumnsResponse',
     };
@@ -88,7 +87,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/cells/columns/';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/cells/columns/';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -128,9 +127,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -144,21 +140,21 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => 'The worksheet name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'offset' => {
      	datatype => 'int',
      	base_name => 'offset',
-     	description => 'The workdook folder.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
@@ -172,14 +168,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
