@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetListObjectsRequest.name : The file name.  ,
-# GetWorksheetListObjectsRequest.sheetName : The worksheet name.  ,
-# GetWorksheetListObjectsRequest.folder : The folder where the file is situated.  ,
-# GetWorksheetListObjectsRequest.storageName : The storage name where the file is situated.   
+# GetWorksheetListObjectsRequest.name :   ,
+# GetWorksheetListObjectsRequest.sheetName :   ,
+# GetWorksheetListObjectsRequest.folder :   ,
+# GetWorksheetListObjectsRequest.storageName :    
 
 {
     my $params = {
@@ -74,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_list_objects' } = { 
-    	summary => 'Retrieve descriptions of ListObjects in the worksheet.',
+    	summary => '',
         params => $params,
         returns => 'ListObjectsResponse',
     };
@@ -86,7 +85,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/listobjects';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/listobjects';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -118,9 +117,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -134,28 +130,28 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => 'The worksheet name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
