@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetRowsRequest.name : The file name.  ,
-# GetWorksheetRowsRequest.sheetName : The worksheet name.  ,
-# GetWorksheetRowsRequest.offset : Row offset.  ,
-# GetWorksheetRowsRequest.count : Display rows number.  ,
-# GetWorksheetRowsRequest.folder : The folder where the file is situated.  ,
-# GetWorksheetRowsRequest.storageName : The storage name where the file is situated.   
+# GetWorksheetRowsRequest.name :   ,
+# GetWorksheetRowsRequest.sheetName :   ,
+# GetWorksheetRowsRequest.offset :   ,
+# GetWorksheetRowsRequest.count :   ,
+# GetWorksheetRowsRequest.folder :   ,
+# GetWorksheetRowsRequest.storageName :    
 
 {
     my $params = {
@@ -76,7 +75,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_rows' } = { 
-    	summary => 'Retrieve descriptions of rows in the worksheet.',
+    	summary => '',
         params => $params,
         returns => 'RowsResponse',
     };
@@ -88,7 +87,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/cells/rows/';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/cells/rows/';
 
     my $_method = 'GET';
     my $query_params = {};
@@ -128,9 +127,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -144,42 +140,42 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => 'The worksheet name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'offset' => {
      	datatype => 'int',
      	base_name => 'offset',
-     	description => 'Row offset.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'count' => {
      	datatype => 'int',
      	base_name => 'count',
-     	description => 'Display rows number.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
