@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,7 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PostAnalyzeExcelRequest.analyzeExcelRequest : Excel files and analysis output requirements   
+# PostAnalyzeExcelRequest.analyzeExcelRequest :    
 
 {
     my $params = {
@@ -71,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_analyze_excel' } = { 
-    	summary => 'Perform business analysis of data in Excel files.',
+    	summary => '',
         params => $params,
         returns => 'ARRAY[AnalyzedResult]',
     };
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/analyze';
+    my $_resource_path = '/cells/analyze';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -100,14 +99,11 @@ sub run_http_request {
  
     my $_body_data;
 
-
     # body params
     if (defined $self->analyze_excel_request) {
+        #$_body_data = $self->analyze_excel_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->analyze_excel_request);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -121,7 +117,7 @@ __PACKAGE__->method_documentation({
      'analyze_excel_request' => {
      	datatype => 'AnalyzeExcelRequest',
      	base_name => 'analyzeExcelRequest',
-     	description => 'Excel files and analysis output requirements',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
