@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,7 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PostBatchConvertRequest.batchConvertRequest : BatchConvertRequest Batch conversion file request.    
+# PostBatchConvertRequest.batchConvertRequest :    
 
 {
     my $params = {
@@ -71,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_batch_convert' } = { 
-    	summary => 'Batch converting files that meet specific matching conditions.',
+    	summary => '',
         params => $params,
         returns => 'string',
     };
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/batch/convert';
+    my $_resource_path = '/cells/batch/convert';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -100,14 +99,11 @@ sub run_http_request {
  
     my $_body_data;
 
-
     # body params
     if (defined $self->batch_convert_request) {
+        #$_body_data = $self->batch_convert_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->batch_convert_request);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -121,7 +117,7 @@ __PACKAGE__->method_documentation({
      'batch_convert_request' => {
      	datatype => 'BatchConvertRequest',
      	base_name => 'batchConvertRequest',
-     	description => 'BatchConvertRequest Batch conversion file request. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
