@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,15 +59,15 @@ sub new {
 
 
 # Run Operation Request
-# PostClearContentsRequest.name : The file name.  ,
-# PostClearContentsRequest.sheetName : The worksheet name.  ,
-# PostClearContentsRequest.range : Represents the range to which the specified cells applies.  ,
-# PostClearContentsRequest.startRow : The start row index.  ,
-# PostClearContentsRequest.startColumn : The start column index.  ,
-# PostClearContentsRequest.endRow : The end row index.  ,
-# PostClearContentsRequest.endColumn : The end column index.  ,
-# PostClearContentsRequest.folder : The folder where the file is situated.  ,
-# PostClearContentsRequest.storageName : The storage name where the file is situated.   
+# PostClearContentsRequest.name :   ,
+# PostClearContentsRequest.sheetName :   ,
+# PostClearContentsRequest.range :   ,
+# PostClearContentsRequest.startRow :   ,
+# PostClearContentsRequest.startColumn :   ,
+# PostClearContentsRequest.endRow :   ,
+# PostClearContentsRequest.endColumn :   ,
+# PostClearContentsRequest.folder :   ,
+# PostClearContentsRequest.storageName :    
 
 {
     my $params = {
@@ -78,7 +78,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_clear_contents' } = { 
-    	summary => 'Clear cell area contents in the worksheet.',
+    	summary => '',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -155,63 +155,63 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => 'The worksheet name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'range' => {
      	datatype => 'string',
      	base_name => 'range',
-     	description => 'Represents the range to which the specified cells applies.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'start_row' => {
      	datatype => 'int',
      	base_name => 'startRow',
-     	description => 'The start row index.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'start_column' => {
      	datatype => 'int',
      	base_name => 'startColumn',
-     	description => 'The start column index.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'end_row' => {
      	datatype => 'int',
      	base_name => 'endRow',
-     	description => 'The end row index.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'end_column' => {
      	datatype => 'int',
      	base_name => 'endColumn',
-     	description => 'The end column index.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
