@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostDigitalSignatureRequest.name : The file name.  ,
-# PostDigitalSignatureRequest.digitalsignaturefile : The digital signature file path should include both the folder and the file name, along with the extension.  ,
-# PostDigitalSignatureRequest.password : The password needed to open an Excel file.  ,
-# PostDigitalSignatureRequest.folder : The folder where the file is situated.  ,
-# PostDigitalSignatureRequest.storageName : The storage name where the file is situated.   
+# PostDigitalSignatureRequest.name :   ,
+# PostDigitalSignatureRequest.digitalsignaturefile :   ,
+# PostDigitalSignatureRequest.password :   ,
+# PostDigitalSignatureRequest.folder :   ,
+# PostDigitalSignatureRequest.storageName :    
 
 {
     my $params = {
@@ -75,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_digital_signature' } = { 
-    	summary => 'Excel file digital signature.',
+    	summary => '',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -87,7 +86,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/digitalsignature';
+    my $_resource_path = '/cells/{name}/digitalsignature';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -121,9 +120,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -137,35 +133,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'digitalsignaturefile' => {
      	datatype => 'string',
      	base_name => 'digitalsignaturefile',
-     	description => 'The digital signature file path should include both the folder and the file name, along with the extension.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => 'The password needed to open an Excel file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'The folder where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'The storage name where the file is situated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
