@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -87,7 +86,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/calculateformula';
+    my $_resource_path = '/cells/{name}/calculateformula';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -118,14 +117,11 @@ sub run_http_request {
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->options) {
+        #$_body_data = $self->options;
          $_body_data = JSON->new->convert_blessed->encode( $self->options);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
