@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -71,9 +70,7 @@ sub new {
 # PostWorkbookSaveAsRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
 # PostWorkbookSaveAsRequest.region : The regional settings for workbook.  ,
 # PostWorkbookSaveAsRequest.pageWideFitOnPerSheet : The page wide fit on worksheet.  ,
-# PostWorkbookSaveAsRequest.pageTallFitOnPerSheet : The page tall fit on worksheet.  ,
-# PostWorkbookSaveAsRequest.onePagePerSheet :   ,
-# PostWorkbookSaveAsRequest.FontsLocation : Use Custom fonts.   
+# PostWorkbookSaveAsRequest.pageTallFitOnPerSheet : The page tall fit on worksheet.   
 
 {
     my $params = {
@@ -96,7 +93,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/SaveAs';
+    my $_resource_path = '/cells/{name}/SaveAs';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -152,25 +149,14 @@ sub run_http_request {
 
     if(defined $self->page_tall_fit_on_per_sheet){
         $query_params->{'pageTallFitOnPerSheet'} = $client->to_query_value($self->page_tall_fit_on_per_sheet);      
-    }
-
-    if(defined $self->one_page_per_sheet){
-        $query_params->{'onePagePerSheet'} = $client->to_query_value($self->one_page_per_sheet);      
-    }
-
-    if(defined $self->fonts_location){
-        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->save_options) {
+        #$_body_data = $self->save_options;
          $_body_data = JSON->new->convert_blessed->encode( $self->save_options);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -263,20 +249,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'pageTallFitOnPerSheet',
      	description => 'The page tall fit on worksheet.',
      	format => '',
-     	read_only => '',
-     		},
-     'one_page_per_sheet' => {
-     	datatype => 'string',
-     	base_name => 'onePagePerSheet',
-     	description => '',
-     	format => '',
-     	read_only => '',
-     		},
-     'fonts_location' => {
-     	datatype => 'string',
-     	base_name => 'FontsLocation',
-     	description => 'Use Custom fonts.',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -294,9 +266,7 @@ __PACKAGE__->attribute_map( {
     'check_excel_restriction' => 'checkExcelRestriction',
     'region' => 'region',
     'page_wide_fit_on_per_sheet' => 'pageWideFitOnPerSheet',
-    'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet',
-    'one_page_per_sheet' => 'onePagePerSheet',
-    'fonts_location' => 'FontsLocation' 
+    'page_tall_fit_on_per_sheet' => 'pageTallFitOnPerSheet' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
