@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -77,7 +76,7 @@ sub new {
     __PACKAGE__->method_documentation->{ 'post_worksheet_cells_range_to_image' } = { 
     	summary => '',
         params => $params,
-        returns => 'string',
+        returns => 'CellsCloudResponse',
     };
 }
 
@@ -87,7 +86,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/ranges/convertToImage';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/ranges/convertToImage';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -120,14 +119,11 @@ sub run_http_request {
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->range_convert_request) {
+        #$_body_data = $self->range_convert_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->range_convert_request);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
