@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -89,7 +88,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}';
+    my $_resource_path = '/cells/{name}';
 
     my $_method = 'PUT';
     my $query_params = {};
@@ -131,9 +130,6 @@ sub run_http_request {
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
