@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -92,7 +91,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/conditionalFormattings/{index}';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/conditionalFormattings/{index}';
 
     my $_method = 'PUT';
     my $query_params = {};
@@ -150,9 +149,6 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
