@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -85,7 +84,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v4.0/cells/storage/file/{path}';
+    my $_resource_path = '/cells/storage/file/{path}';
 
     my $_method = 'PUT';
     my $query_params = {};
@@ -107,12 +106,14 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
-
+ 
 
     if (defined $self->upload_files) {   
-        $form_params->{basename($self->upload_files)} = [$self->upload_files ,basename($self->upload_files),'application/octet-stream'];
-    }
- 
+        my $map_file = $self->upload_files;
+        while ( my ($filename,$value) = each( %$map_file ) ) {
+                $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
+        }
+    } 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
